===================
Built-in Extensions
===================

The followig ready-to-use classes give you this exact extra
functionality you need for your plugin manager:


.. toctree::
   :maxdepth: 1

   VersionedPluginManager
   ConfigurablePluginManager
   AutoInstallPluginManager
   FilteredPluginManager


The following item offer customization for the way plugins are
described and detected:

.. toctree::
   :maxdepth: 1

   PluginFileLocator


If you want to build your own extensions, have a look at the following
interfaces:

.. toctree::
   :maxdepth: 1

   IPluginLocator
   PluginManagerDecorator
